@@ -1,9 +1,10 @@
 use anyhow::Result;
-use console::Term;
 use content_inspector::ContentType;
+use crossterm::tty::IsTty;
 use hexyl::{BorderStyle, Printer};
 use owo_colors::OwoColorize;
-use std::io::Write;
+use std::io::BufRead;
+use std::io::{self, Write};
 use yozuk_sdk::prelude::*;
 
 pub struct TerminalPrinter;
@@ -14,7 +15,7 @@ impl TerminalPrinter {
     }
 
     pub fn print_commands(&self, commands: &[CommandArgs]) -> Result<()> {
-        let mut stdout = Term::stdout();
+        let mut stdout = io::stdout();
         for cmd in commands {
             writeln!(&mut stdout, "{}", shell_words::join(&cmd.args))?;
         }
@@ -22,8 +23,9 @@ impl TerminalPrinter {
     }
 
     pub fn print_result(&self, output: &Output) -> Result<()> {
-        let mut stdout = Term::stdout();
-        let mut stderr = Term::stderr();
+        let mut stdout = io::stdout();
+        let mut stderr = io::stderr();
+        let stdin = io::stdin();
 
         let title = if output.title.is_empty() {
             String::new()
@@ -54,15 +56,23 @@ impl TerminalPrinter {
                     )?;
                 }
                 Block::Spoiler(spoiler) => {
-                    let term = Term::stderr();
+                    use crossterm::{
+                        cursor::MoveToPreviousLine,
+                        execute,
+                        terminal::{Clear, ClearType},
+                    };
                     write!(
                         &mut stderr,
                         "{} Press enter to show {}",
                         "Spoiler:".bold(),
                         spoiler.title.on_red()
                     )?;
-                    term.read_line()?;
-                    term.clear_last_lines(1)?;
+                    stdin.lock().lines().next().unwrap()?;
+                    execute!(
+                        stderr,
+                        MoveToPreviousLine(1),
+                        Clear(ClearType::FromCursorDown)
+                    )?;
                     writeln!(
                         &mut stderr,
                         "{}{} {}",
@@ -71,8 +81,12 @@ impl TerminalPrinter {
                         spoiler.data.unsecure()
                     )?;
                     write!(&mut stderr, "{}", "Press enter to hide".dimmed())?;
-                    term.read_line()?;
-                    term.clear_last_lines(2)?;
+                    stdin.lock().lines().next().unwrap()?;
+                    execute!(
+                        stderr,
+                        MoveToPreviousLine(2),
+                        Clear(ClearType::FromCursorDown)
+                    )?;
                 }
                 _ => writeln!(&mut stderr, "{}", "[unimplemented]".dimmed())?,
             }
@@ -82,7 +96,7 @@ impl TerminalPrinter {
     }
 
     pub fn print_error(&self, outputs: &[Output]) -> Result<()> {
-        let mut stderr = Term::stderr();
+        let mut stderr = io::stderr();
 
         let output = &outputs[0];
         let title = if output.title.is_empty() {
@@ -103,20 +117,20 @@ impl TerminalPrinter {
     }
 
     pub fn print_error_str(&self, err: &str) -> Result<()> {
-        let mut stderr = Term::stderr();
+        let mut stderr = io::stderr();
         writeln!(&mut stderr, "{}", err.red())?;
         Ok(())
     }
 
     pub fn print_suggest(&self, suggest: &str) -> Result<()> {
-        let mut stderr = Term::stderr();
+        let mut stderr = io::stderr();
         writeln!(&mut stderr, "Did you mean {} ?", suggest.italic())?;
         Ok(())
     }
 
     fn print_binary(&self, data: &[u8]) -> Result<()> {
-        let mut stdout = Term::stdout();
-        if console::user_attended() {
+        let mut stdout = io::stdout();
+        if stdout.is_tty() {
             let show_color = true;
             let use_squeezing = false;
             let border_style = BorderStyle::Unicode;
